/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2, OnChanges } from '@angular/core';
import { TypographyFontSize } from './models/font-size';
import { TypographyFontWeight } from './models/font-weight';
import { TypographyTextAlign } from './models/text-align';
import { TypographyTextTransform } from './models/text-transform';
import { TypographyThemeColor } from './models/theme-color';
import { TypographyVariant } from './models/variant';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Typography directive for Angular]({% slug overview_typography %}).
 * Use this directive to represent element types in a uniform way by relying on the predefined Kendo theme classes.
 *
 * @example
 * ```html
 * <div kendoTypography variant="k-h1"></div>
 * ```
 */
export declare class TypographyDirective implements OnChanges {
    elementWrapper: ElementRef;
    private renderer;
    private element;
    /**
     * Specifies the element `variant` class that will be applied.
     */
    variant: TypographyVariant;
    /**
     * Sets the element `font-size` style.
     */
    fontSize: TypographyFontSize;
    /**
     * Sets the element `font-weight` style.
     */
    fontWeight: TypographyFontWeight;
    /**
     * Sets the element `text-align` style.
     */
    textAlign: TypographyTextAlign;
    /**
     * Sets the element `text-transform` style.
     */
    textTransform: TypographyTextTransform;
    /**
     * Applies the `theme-color` to the element.
     */
    themeColor: TypographyThemeColor;
    private typographyClasses;
    constructor(elementWrapper: ElementRef, renderer: Renderer2, element: ElementRef);
    ngOnChanges(): void;
    private variantClass;
    private themeColorClass;
    private textAlignClass;
    private fontWeightClass;
    private fontSizeClass;
    private textTransformClass;
    private setTypographyClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<TypographyDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TypographyDirective, "[kendoTypography]", ["kendoTypography"], { "variant": { "alias": "variant"; "required": false; }; "fontSize": { "alias": "fontSize"; "required": false; }; "fontWeight": { "alias": "fontWeight"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "textTransform": { "alias": "textTransform"; "required": false; }; "themeColor": { "alias": "themeColor"; "required": false; }; }, {}, never, never, true, never>;
}
